// src/index.ts
function renderTemplateWithJS(template, context, options = {}) {
  const [openDelimiter, closeDelimiter] = options.delimiters || ["{", "}"];
  const escOpenDelimiter = openDelimiter.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
  const escCloseDelimiter = closeDelimiter.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
  const expressionRegex = new RegExp(`${escOpenDelimiter}([^${escOpenDelimiter}${escCloseDelimiter}]*?)${escCloseDelimiter}`, "g");
  const singleExpressionRegex = new RegExp(`^${escOpenDelimiter}([\\s\\S]*?)${escCloseDelimiter}$`);
  const mergedContext = {
    ...context,
    ...options.contextExtensions
  };
  if (options.returnRawValues) {
    const trimmedTemplate = template.trim();
    const match = trimmedTemplate.match(singleExpressionRegex);
    if (match) {
      try {
        const expression = match[1].trim();
        const contextKeys = Object.keys(mergedContext);
        const contextValues = Object.values(mergedContext);
        const isIIFE = /^\s*\(.*\)\s*\(.*\)/.test(expression) || // (function(){})() pattern
        /^\s*\(.*=>.*\)\s*\(/.test(expression);
        const hasDeclarations = /\b(const|let|var|function|class)\b/.test(expression);
        const hasMultipleStatements = expression.includes(";");
        let result;
        if (isIIFE) {
          try {
            const contextKeys2 = Object.keys(mergedContext);
            const contextValues2 = Object.values(mergedContext);
            const functionBody = `return (${expression});`;
            const iifeFn = Function.constructor.apply(null, [...contextKeys2, functionBody]);
            result = iifeFn(...contextValues2);
          } catch (error) {
            console.error(`Error executing IIFE:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        } else if (hasDeclarations || hasMultipleStatements) {
          let functionBody;
          if (expression.includes("return ")) {
            functionBody = expression;
          } else {
            const lastSemicolonIndex = expression.lastIndexOf(";");
            if (lastSemicolonIndex !== -1 && lastSemicolonIndex < expression.length - 1) {
              const lastExpression = expression.substring(lastSemicolonIndex + 1).trim();
              functionBody = `${expression.substring(0, lastSemicolonIndex + 1)} return ${lastExpression};`;
            } else {
              functionBody = `${expression} return undefined;`;
            }
          }
          try {
            const evaluator = Function.constructor.apply(null, [...contextKeys, functionBody]);
            result = evaluator(...contextValues);
          } catch (error) {
            console.error(`Error executing complex expression:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        } else {
          try {
            const functionBody = `return ${expression};`;
            const evaluator = Function.constructor.apply(null, [...contextKeys, functionBody]);
            result = evaluator(...contextValues);
          } catch (error) {
            console.error(`Error executing simple expression:`, error);
            return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
          }
        }
        return result;
      } catch (error) {
        console.error(`Error evaluating expression:`, error);
        return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
      }
    }
  }
  return template.replace(expressionRegex, (match, expression) => {
    try {
      const contextKeys = Object.keys(mergedContext);
      const contextValues = Object.values(mergedContext);
      const evaluator = new Function(...contextKeys, `return (${expression});`);
      const result = evaluator(...contextValues);
      if (result === void 0 || result === null) {
        return "";
      }
      return String(result);
    } catch (error) {
      console.error(`Error evaluating expression "${expression}":`, error);
      return `[Error: ${error instanceof Error ? error.message : String(error)}]`;
    }
  });
}

export { renderTemplateWithJS };
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map